@@ -1,10 +1,5 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-from __future__ import unicode_literals
-
 import signal
 
 import gdb
@@ -20,6 +15,7 @@ import pwndbg.commands.aslr
 import pwndbg.commands.auxv
 import pwndbg.commands.canary
 import pwndbg.commands.checksec
+import pwndbg.commands.comments
 import pwndbg.commands.config
 import pwndbg.commands.context
 import pwndbg.commands.cpsr
@@ -27,6 +23,7 @@ import pwndbg.commands.dt
 import pwndbg.commands.dumpargs
 import pwndbg.commands.elf
 import pwndbg.commands.gdbinit
+import pwndbg.commands.ghidra
 import pwndbg.commands.got
 import pwndbg.commands.heap
 import pwndbg.commands.hexdump
@@ -68,7 +65,6 @@ import pwndbg.elf
 import pwndbg.exception
 import pwndbg.gdbutils.functions
 import pwndbg.heap
-import pwndbg.inthook
 import pwndbg.memory
 import pwndbg.net
 import pwndbg.proc
@@ -88,6 +84,7 @@ version = __version__
 
 try:
     import unicorn
+
     import pwndbg.emu
 except:
     pass
@@ -163,3 +160,6 @@ signal.signal(signal.SIGWINCH, lambda signum, frame: gdb.execute("set width %i"
 # After GDB gets the fix, we should disable this only for bugged GDB versions.
 if 1:
     gdb.execute('set remote search-memory-packet off')
+
+# Reading Comment file 
+pwndbg.commands.comments.init()
