@@ -1,9 +1,5 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-from __future__ import unicode_literals
 
 import pwndbg.color.theme as theme
 import pwndbg.config as config
@@ -21,6 +17,7 @@ config_banner_color             = theme.ColoredParameter('banner-color', 'blue',
 config_banner_title             = theme.ColoredParameter('banner-title-color', 'none', 'color for banner title')
 config_register_changed_color   = theme.ColoredParameter('context-register-changed-color', 'normal', 'color for registers label (change marker)')
 config_register_changed_marker  = theme.Parameter('context-register-changed-marker', '*', 'change marker for registers label')
+config_comment                  = theme.ColoredParameter('comment-color', 'gray', 'color for comment')
 
 def prefix(x):
     return generateColorFunction(config.code_prefix_color)(x)
@@ -54,3 +51,28 @@ def banner(x):
 
 def banner_title(x):
     return generateColorFunction(config.banner_title_color)(x)
+
+def comment(x):
+    return generateColorFunction(config.comment_color)(x)
+
+def format_flags(value, flags, last=None):
+    desc = flag_value('%#x' % value)
+    if not flags:
+        return desc
+
+    names = []
+    for name, bit in flags.items():
+        bit = 1<<bit
+        if value & bit:
+            name = name.upper()
+            name = flag_set(name)
+        else:
+            name = name.lower()
+            name = flag_unset(name)
+
+        if last is not None and value & bit != last & bit:
+            name = flag_changed(name)
+        names.append(name)
+
+    return '%s %s %s %s' % (desc, flag_bracket('['), ' '.join(names), flag_bracket(']'))
+
