@@ -1,9 +1,5 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-from __future__ import unicode_literals
 
 import argparse
 
@@ -16,17 +12,16 @@ from pwndbg.color import message
 
 options = {'on':'off', 'off':'on'}
 
-parser = argparse.ArgumentParser(description='Inspect or modify ASLR status')
+parser = argparse.ArgumentParser(description='''
+Check the current ASLR status, or turn it on/off.
+
+Does not take effect until the program is restarted.
+''')
 parser.add_argument('state', nargs='?', type=str, choices=options,
                     help="Turn ASLR on or off (takes effect when target is started)")
 
 @pwndbg.commands.ArgparsedCommand(parser)
 def aslr(state=None):
-    """
-    Check the current ASLR status, or turn it on/off.
-
-    Does not take effect until the program is restarted.
-    """
     if state:
         gdb.execute('set disable-randomization %s' % options[state], 
                     from_tty=False, to_string=True)
@@ -34,10 +29,10 @@ def aslr(state=None):
         if pwndbg.proc.alive:
             print("Change will take effect when the process restarts")
 
-    aslr = pwndbg.vmmap.check_aslr()
+    aslr, method = pwndbg.vmmap.check_aslr()
     status = message.off('OFF')
 
     if aslr:
         status = message.on('ON')
 
-    print("ASLR is %s" % status)
+    print("ASLR is %s (%s)" % (status, method))
