@@ -5,12 +5,6 @@ Compatibility functionality for GDBINIT users.
 
 https://github.com/gdbinit/Gdbinit/blob/master/gdbinit
 """
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-from __future__ import unicode_literals
-
-import argparse
 
 import gdb
 
