@@ -1,14 +1,8 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-from __future__ import unicode_literals
 
 import argparse
-import codecs
 
-import gdb
 from capstone import *
 
 import pwndbg.arguments
@@ -17,6 +11,7 @@ import pwndbg.color.context as C
 import pwndbg.color.disasm as D
 import pwndbg.color.nearpc as N
 import pwndbg.color.theme
+import pwndbg.commands.comments
 import pwndbg.config
 import pwndbg.disasm
 import pwndbg.functions
@@ -166,6 +161,12 @@ def nearpc(pc=None, lines=None, to_string=False, emulate=False):
             if syscall_name:
                 line += ' <%s>' % N.syscall_name(syscall_name)
 
+        # For Comment Function
+        try:
+            line += " "*10 + C.comment(pwndbg.commands.comments.file_lists[pwndbg.proc.exe][hex(instr.address)])
+        except:
+            pass
+
         result.append(line)
 
         # For call instructions, attempt to resolve the target and
