@@ -3,10 +3,6 @@
 """
 Dumps all pwndbg-specific theme configuration points.
 """
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-from __future__ import unicode_literals
 
 import argparse
 
