@@ -1,21 +1,12 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-from __future__ import unicode_literals
 
-import collections
-
-import capstone
 import gdb
 from capstone import *
 
 import pwndbg.memoize
 import pwndbg.symbol
 
-CS_OP_IMM
-
 debug = False
 
 groups = {v:k for k,v in globals().items() if k.startswith('CS_GRP_')}
@@ -27,7 +18,7 @@ for value1, name1 in dict(access).items():
         access.setdefault(value1 | value2, '%s | %s' % (name1, name2))
 
 
-class DisassemblyAssistant(object):
+class DisassemblyAssistant:
     # Registry of all instances, {architecture: instance}
     assistants = {}
 
