@@ -5,24 +5,19 @@ Retrieve files from the debuggee's filesystem.  Useful when
 debugging a remote process over SSH or similar, where e.g.
 /proc/FOO/maps is needed from the remote system.
 """
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-from __future__ import unicode_literals
 
 import binascii
-import errno as _errno
 import os
-import subprocess
 import tempfile
 
 import gdb
 
 import pwndbg.qemu
 import pwndbg.remote
+import pwndbg.symbol
 
 
-def get_file(path, recurse=1):
+def get_file(path):
     """
     Downloads the specified file from the system where the current process is
     being debugged.
@@ -31,11 +26,11 @@ def get_file(path, recurse=1):
         The local path to the file
     """
     local_path = path
-
-    if pwndbg.qemu.root() and recurse:
-        return os.path.join(pwndbg.qemu.binfmt_root, path)
+    qemu_root = pwndbg.qemu.root()
+    if qemu_root:
+        return os.path.join(qemu_root, path)
     elif pwndbg.remote.is_remote() and not pwndbg.qemu.is_qemu():
-        local_path = tempfile.mktemp()
+        local_path = tempfile.mktemp(dir=pwndbg.symbol.remote_files_dir)
         error      = None
         try:
             error = gdb.execute('remote get "%s" "%s"' % (path, local_path),
@@ -49,7 +44,7 @@ def get_file(path, recurse=1):
 
     return local_path
 
-def get(path, recurse=1):
+def get(path):
     """
     Retrieves the contents of the specified file on the system
     where the current process is being debugged.
@@ -57,7 +52,7 @@ def get(path, recurse=1):
     Returns:
         A byte array, or None.
     """
-    local_path = get_file(path, recurse)
+    local_path = get_file(path)
 
     try:
         with open(local_path,'rb') as f:
