@@ -1,15 +1,8 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-from __future__ import unicode_literals
-
-import pwndbg.events
-import pwndbg.symbol
 
 
-class BaseHeap(object):
+class BaseHeap:
     """Heap abstraction layer."""
 
     def breakpoint(event):
