@@ -4,20 +4,11 @@
 Provides functionality to circumvent GDB's hooks on sys.stdin and sys.stdout
 which prevent output from appearing on-screen inside of certain event handlers.
 """
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-from __future__ import unicode_literals
 
-import codecs
-import io
-import os
 import sys
 
-import gdb
 
-
-class Stdio(object):
+class Stdio:
     queue = []
 
     def __enter__(self, *a, **kw):
