@@ -4,10 +4,6 @@
 Common types, and routines for manually loading types from file
 via GCC.
 """
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-from __future__ import unicode_literals
 
 import glob
 import os
