@@ -7,17 +7,11 @@ address ranges with various ELF files and permissions.
 The reason that we need robustness is that not every operating
 system has /proc/$$/maps, which backs 'info proc mapping'.
 """
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-from __future__ import unicode_literals
-
 import bisect
 import os
 import sys
 
 import gdb
-import six
 
 import pwndbg.abi
 import pwndbg.elf
@@ -200,8 +194,7 @@ def proc_pid_maps():
     else:
         return tuple()
 
-    if six.PY3:
-        data = data.decode()
+    data = data.decode()
 
     pages = []
     for line in data.splitlines():
@@ -451,7 +444,7 @@ def check_aslr():
         data = pwndbg.file.get('/proc/sys/kernel/randomize_va_space')
         if b'0' in data:
             vmmap.aslr = False
-            return vmmap.aslr
+            return vmmap.aslr, 'kernel.randomize_va_space == 0'
     except Exception as e:
         print("Could not check ASLR: Couldn't get randomize_va_space")
         pass
@@ -463,7 +456,7 @@ def check_aslr():
             personality = int(data, 16)
             if personality & 0x40000 == 0:
                 vmmap.aslr = True
-            return vmmap.aslr
+            return vmmap.aslr, 'read status from process\' personality'
         except:
             print("Could not check ASLR: Couldn't get personality")
             pass
@@ -476,7 +469,7 @@ def check_aslr():
     if "is off." in output:
         vmmap.aslr = True
 
-    return vmmap.aslr
+    return vmmap.aslr, 'show disable-randomization'
 
 @pwndbg.events.cont
 def mark_pc_as_executable():
