@@ -1,12 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-from __future__ import unicode_literals
 
-from re import search
-from subprocess import STDOUT
 from subprocess import CalledProcessError
 
 import pwndbg.commands
